/*!
  \file qpromptshow.h
  \brief Declaration of QPromptShow class.
*/
#include <qapplication.h>

class QBigTextWidget;
class QFileSelectWidget;
class QPushButton;
class QListBox;
class ifstream;

//! The prompt showing application.
/*!
  This class takes over the execution of the program and does all the
  stuff that should be done to make for a complete application.

  The application accepts any given text file and allows showing it
  line by line with the lines beginning with <tt>#</tt> treaten as
  comments and blank lines delimiting sections. At the end of each
  section is the appropriate message box is shown to the user.
*/
class QPromptShow : public QApplication
{
  Q_OBJECT
public:
  //! Constructor.
  QPromptShow( int argc = 0, char** argv = 0);
  //! Destructor.
  ~QPromptShow();
  
public slots:
  //! Pop up the options dialog and set them appropriately.
  void setOptions();
  //! Start showing the prompts.
  void startShow();
  //! Show the next prompt.
  void nextPrompt();
  //! Abort the current show.
  void endShow();

protected:
  //! Main display area.
  QBigTextWidget* display;
  //! File select widget.
  QFileSelectWidget* file_select;
  //! Start show/next button.
  QPushButton* start_button;
  //! End show/quit button.
  QPushButton* end_button;
  //! Opyions button.
  QPushButton* options_button;
  //! The list with available sections in the file
  QListBox * section_list;
  //! The file from which prompts are read.
  ifstream* infile;



protected slots:
  //! Rescan the prompt file to update the sections list.
  void rescanFile( const char* );
  //! Skip to next section.
  int nextSection();
};
