/*! \file qfileselectwidget.h
  \brief Declaration of QFileSelectWidget class.
*/
#include <qwidget.h>

class QPushButton;
class QLineEdit;

//! Simple widget for selecting filename.
/*! 
  This widget allows selecting the filename through browse function or
  by typing its name in the line edit. It consists therefore from two
  sub-widgets: a pushbutton and a line edit. The children are placed
  in QHBoxLayout with line edit being able to stretch horizontally.  
*/
class QFileSelectWidget : public QWidget
{
  Q_OBJECT
public:
  //! Constructor.
  QFileSelectWidget(QWidget* parent=0, const char* name=0, WFlags f=0 ); 
  //! Destructor.
  virtual ~QFileSelectWidget();
  //! Returns file name.
  const char* fileName() const;

signals:
  //! A signal emited when the file name has changed.
  void fileNameChanged( const char* );

public slots:
  //! Allows setting the file name.
  void setFileName( const char* );
  //! Pops up the file open dialog.
  void browseFileName();
  //! Overloaded from QWidget.
  void setEnabled( bool e );

protected:
  //! The line edit widget with selected file name in it.
  QLineEdit* file_name;
  //! The push button that activates brosing through files.
  QPushButton* browse_button;

protected slots:
  //! A protected slot used to emit fileNameChanged( const char* ) signal
  void emitChange();

};
